from deatool.scripts.run import run


if __name__ == '__main__':
    run()